==> open5gs_2.4.9.tar.xz: BUILD/lib/nas/5gs/support/cache/nas-msg-65.py <==
ies = []
ies.append({ "iei" : "", "value" : "5GS registration type", "type" : "5GS registration type", "reference" : "9.11.3.7", "presence" : "M", "format" : "V", "length" : "1/2"})
ies.append({ "iei" : "", "value" : "5GS mobile identity", "type" : "5GS mobile identity", "reference" : "9.11.3.4", "presence" : "M", "format" : "LV-E", "length" : "6-n"})
ies.append({ "iei" : "C-", "value" : "Non-current native NAS key set identifier", "type" : "key set identifier", "reference" : "9.11.3.32", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "10", "value" : "5GMM capability", "type" : "5GMM capability", "reference" : "9.11.3.1", "presence" : "O", "format" : "TLV", "length" : "3-15"})
ies.append({ "iei" : "2E", "value" : "UE security capability", "type" : "UE security capability", "reference" : "9.11.3.54", "presence" : "O", "format" : "TLV", "length" : "4-10"})
ies.append({ "iei" : "2F", "value" : "Requested NSSAI", "type" : "NSSAI", "reference" : "9.11.3.37", "presence" : "O", "format" : "TLV", "length" : "4-74"})
ies.append({ "iei" : "52", "value" : "Last visited registered TAI", "type" : "5GS tracking area identity", "reference" : "9.11.3.8", "presence" : "O", "format" : "TV", "length" : "7"})
ies.append({ "iei" : "17", "value" : "S1 UE network capability", "type" : "S1 UE network capability", "reference" : "9.11.3.48", "presence" : "O", "format" : "TLV", "length" : "4-15"})
ies.append({ "iei" : "40", "value" : "Uplink data status", "type" : "Uplink data status", "reference" : "9.11.3.57", "presence" : "O", "format" : "TLV", "length" : "4-34"})
ies.append({ "iei" : "50", "value" : "PDU session status", "type" : "PDU session status", "reference" : "9.11.3.44", "presence" : "O", "format" : "TLV", "length" : "4-34"})
ies.append({ "iei" : "B-", "value" : "MICO indication", "type" : "MICO indication", "reference" : "9.11.3.31", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "2B", "value" : "UE status", "type" : "UE status", "reference" : "9.11.3.56", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "77", "value" : "Additional GUTI", "type" : "5GS mobile identity", "reference" : "9.11.3.4", "presence" : "O", "format" : "TLV-E", "length" : "14"})
ies.append({ "iei" : "25", "value" : "Allowed PDU session status", "type" : "Allowed PDU session status", "reference" : "9.11.3.13", "presence" : "O", "format" : "TLV", "length" : "4-34"})
ies.append({ "iei" : "18", "value" : "UE usage setting", "type" : "UE usage setting", "reference" : "9.11.3.55", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "51", "value" : "Requested DRX parameters", "type" : "5GS DRX parameters", "reference" : "9.11.3.2A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "70", "value" : "EPS NAS message container", "type" : "EPS NAS message container", "reference" : "9.11.3.24", "presence" : "O", "format" : "TLV-E", "length" : "4-n"})
ies.append({ "iei" : "74", "value" : "LADN indication", "type" : "LADN indication", "reference" : "9.11.3.29", "presence" : "O", "format" : "TLV-E", "length" : "3-811"})
ies.append({ "iei" : "8-", "value" : "Payload container type", "type" : "Payload container type", "reference" : "9.11.3.40", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "7B", "value" : "Payload container", "type" : "Payload container", "reference" : "9.11.3.39", "presence" : "O", "format" : "TLV-E", "length" : "4-65538"})
ies.append({ "iei" : "9-", "value" : "Network slicing indication", "type" : "Network slicing indication", "reference" : "9.11.3.36", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "53", "value" : "5GS update type", "type" : "5GS update type", "reference" : "9.11.3.9A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "41", "value" : "Mobile station classmark 2", "type" : "Mobile station classmark 2", "reference" : "9.11.3.31C", "presence" : "O", "format" : "TLV", "length" : "5"})
ies.append({ "iei" : "42", "value" : "Supported codecs", "type" : "Supported codec list", "reference" : "9.11.3.51A", "presence" : "O", "format" : "TLV", "length" : "5-n"})
ies.append({ "iei" : "71", "value" : "NAS message container", "type" : "message container", "reference" : "9.11.3.33", "presence" : "O", "format" : "TLV-E", "length" : "4-n"})
ies.append({ "iei" : "60", "value" : "EPS bearer context status", "type" : "EPS bearer context status", "reference" : "9.11.3.23A", "presence" : "O", "format" : "TLV", "length" : "4"})
ies.append({ "iei" : "6E", "value" : "Requested extended DRX parameters", "type" : "Extended DRX parameters", "reference" : "9.11.3.26A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "6A", "value" : "T3324 value", "type" : "GPRS timer 3", "reference" : "9.11.2.5", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "67", "value" : "UE radio capability ID", "type" : "UE radio capability ID", "reference" : "9.11.3.68", "presence" : "O", "format" : "TLV", "length" : "3-n"})
ies.append({ "iei" : "35", "value" : "Requested mapped NSSAI", "type" : "Mapped NSSAI", "reference" : "9.11.3.31B", "presence" : "O", "format" : "TLV", "length" : "3-42"})
ies.append({ "iei" : "48", "value" : "Additional information requested", "type" : "Additional information requested", "reference" : "9.11.3.12A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "1A", "value" : "Requested WUS assistance information", "type" : "WUS assistance information", "reference" : "9.11.3.71", "presence" : "O", "format" : "TLV", "length" : "3-n"})
ies.append({ "iei" : "A1", "value" : "N5GC indication", "type" : "N5GC indication", "reference" : "9.11.3.72", "presence" : "O", "format" : "T", "length" : "1"})
msg_list[key]["ies"] = ies

==> open5gs_2.6.3.tar.xz: BUILD/lib/nas/5gs/support/cache/nas-msg-65.py <==
ies = []
ies.append({ "iei" : "", "value" : "5GS registration type", "type" : "5GS registration type", "reference" : "9.11.3.7", "presence" : "M", "format" : "V", "length" : "1/2"})
ies.append({ "iei" : "", "value" : "5GS mobile identity", "type" : "5GS mobile identity", "reference" : "9.11.3.4", "presence" : "M", "format" : "LV-E", "length" : "6-n"})
ies.append({ "iei" : "C-", "value" : "Non-current native NAS key set identifier", "type" : "key set identifier", "reference" : "9.11.3.32", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "10", "value" : "5GMM capability", "type" : "5GMM capability", "reference" : "9.11.3.1", "presence" : "O", "format" : "TLV", "length" : "3-15"})
ies.append({ "iei" : "2E", "value" : "UE security capability", "type" : "UE security capability", "reference" : "9.11.3.54", "presence" : "O", "format" : "TLV", "length" : "4-10"})
ies.append({ "iei" : "2F", "value" : "Requested NSSAI", "type" : "NSSAI", "reference" : "9.11.3.37", "presence" : "O", "format" : "TLV", "length" : "4-74"})
ies.append({ "iei" : "52", "value" : "Last visited registered TAI", "type" : "5GS tracking area identity", "reference" : "9.11.3.8", "presence" : "O", "format" : "TV", "length" : "7"})
ies.append({ "iei" : "17", "value" : "S1 UE network capability", "type" : "S1 UE network capability", "reference" : "9.11.3.48", "presence" : "O", "format" : "TLV", "length" : "4-15"})
ies.append({ "iei" : "40", "value" : "Uplink data status", "type" : "Uplink data status", "reference" : "9.11.3.57", "presence" : "O", "format" : "TLV", "length" : "4-34"})
ies.append({ "iei" : "50", "value" : "PDU session status", "type" : "PDU session status", "reference" : "9.11.3.44", "presence" : "O", "format" : "TLV", "length" : "4-34"})
ies.append({ "iei" : "B-", "value" : "MICO indication", "type" : "MICO indication", "reference" : "9.11.3.31", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "2B", "value" : "UE status", "type" : "UE status", "reference" : "9.11.3.56", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "77", "value" : "Additional GUTI", "type" : "5GS mobile identity", "reference" : "9.11.3.4", "presence" : "O", "format" : "TLV-E", "length" : "14"})
ies.append({ "iei" : "25", "value" : "Allowed PDU session status", "type" : "Allowed PDU session status", "reference" : "9.11.3.13", "presence" : "O", "format" : "TLV", "length" : "4-34"})
ies.append({ "iei" : "18", "value" : "UE usage setting", "type" : "UE usage setting", "reference" : "9.11.3.55", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "51", "value" : "Requested DRX parameters", "type" : "5GS DRX parameters", "reference" : "9.11.3.2A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "70", "value" : "EPS NAS message container", "type" : "EPS NAS message container", "reference" : "9.11.3.24", "presence" : "O", "format" : "TLV-E", "length" : "4-n"})
ies.append({ "iei" : "74", "value" : "LADN indication", "type" : "LADN indication", "reference" : "9.11.3.29", "presence" : "O", "format" : "TLV-E", "length" : "3-811"})
ies.append({ "iei" : "8-", "value" : "Payload container type", "type" : "Payload container type", "reference" : "9.11.3.40", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "7B", "value" : "Payload container", "type" : "Payload container", "reference" : "9.11.3.39", "presence" : "O", "format" : "TLV-E", "length" : "4-65538"})
ies.append({ "iei" : "9-", "value" : "Network slicing indication", "type" : "Network slicing indication", "reference" : "9.11.3.36", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "53", "value" : "5GS update type", "type" : "5GS update type", "reference" : "9.11.3.9A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "41", "value" : "Mobile station classmark 2", "type" : "Mobile station classmark 2", "reference" : "9.11.3.31C", "presence" : "O", "format" : "TLV", "length" : "5"})
ies.append({ "iei" : "42", "value" : "Supported codecs", "type" : "Supported codec list", "reference" : "9.11.3.51A", "presence" : "O", "format" : "TLV", "length" : "5-n"})
ies.append({ "iei" : "71", "value" : "NAS message container", "type" : "message container", "reference" : "9.11.3.33", "presence" : "O", "format" : "TLV-E", "length" : "4-n"})
ies.append({ "iei" : "60", "value" : "EPS bearer context status", "type" : "EPS bearer context status", "reference" : "9.11.3.23A", "presence" : "O", "format" : "TLV", "length" : "4"})
ies.append({ "iei" : "6E", "value" : "Requested extended DRX parameters", "type" : "Extended DRX parameters", "reference" : "9.11.3.26A", "presence" : "O", "format" : "TLV", "length" : "3-4"})
ies.append({ "iei" : "6A", "value" : "T3324 value", "type" : "GPRS timer 3", "reference" : "9.11.2.5", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "67", "value" : "UE radio capability ID", "type" : "UE radio capability ID", "reference" : "9.11.3.68", "presence" : "O", "format" : "TLV", "length" : "3-n"})
ies.append({ "iei" : "35", "value" : "Requested mapped NSSAI", "type" : "Mapped NSSAI", "reference" : "9.11.3.31B", "presence" : "O", "format" : "TLV", "length" : "3-42"})
ies.append({ "iei" : "48", "value" : "Additional information requested", "type" : "Additional information requested", "reference" : "9.11.3.12A", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "1A", "value" : "Requested WUS assistance information", "type" : "WUS assistance information", "reference" : "9.11.3.71", "presence" : "O", "format" : "TLV", "length" : "3-n"})
ies.append({ "iei" : "A-", "value" : "N5GC indication", "type" : "N5GC indication", "reference" : "9.11.3.72", "presence" : "O", "format" : "TV", "length" : "1"})
ies.append({ "iei" : "30", "value" : "Requested NB-N1 mode DRX parameters", "type" : "NB-N1 mode DRX parameters", "reference" : "9.11.3.73", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "29", "value" : "UE request type", "type" : "UE request type", "reference" : "9.11.3.76", "presence" : "O", "format" : "TLV", "length" : "3"})
ies.append({ "iei" : "28", "value" : "Paging restriction", "type" : "Paging restriction", "reference" : "9.11.3.77", "presence" : "O", "format" : "TLV", "length" : "3-35"})
ies.append({ "iei" : "72", "value" : "Service-level-AA container", "type" : "Service-level-AA container", "reference" : "9.11.2.10", "presence" : "O", "format" : "TLV-E", "length" : "6-n"})
ies.append({ "iei" : "32", "value" : "NID", "type" : "NID", "reference" : "9.11.3.79", "presence" : "O", "format" : "TLV", "length" : "8"})
ies.append({ "iei" : "16", "value" : "MS determined PLMN with disaster condition", "type" : "PLMN identity", "reference" : "9.11.3.85", "presence" : "O", "format" : "TLV", "length" : "5"})
ies.append({ "iei" : "2A", "value" : "Requested PEIPS assistance information", "type" : "PEIPS assistance information", "reference" : "9.11.3.80", "presence" : "O", "format" : "TLV", "length" : "3-n"})
ies.append({ "iei" : "3B", "value" : "Requested T3512 value", "type" : "GPRS timer 3", "reference" : "9.11.2.5", "presence" : "O", "format" : "TLV", "length" : "3"})
msg_list[key]["ies"] = ies
